Improve this Doc

# Error: $interpolate:noconcat
Multiple Expressions

    Error while interpolating: {0}
    Strict Contextual Escaping disallows interpolations that concatenate multiple expressions when a trusted value is required.  See http://docs.angularjs.org/api/ng.$sce

## Description

This error occurs when performing an interpolation that concatenates multiple expressions when a trusted value is required. Concatenating expressions makes it hard to reason about whether some combination of concatenated values are unsafe to use and could easily lead to XSS.

For more information about how AngularJS helps keep your app secure, refer to the $sce API doc.